cmoncrawl.processor.pipeline.extractor.IExtractor.extract
=========================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: IExtractor.extract